import grabgpu.gpuinfo as gpuinfo
import time

def get_idle(device_ids=[]):
    for device_id in device_ids:
        gpu_status = gpuinfo.get(device_id=device_id)
        if gpu_status['memory_used'] < 100:
            return device_id

    return None

def wait_until_available(device_ids=[], timeout=1000000):
    base_time = time.time()
    while True:
        idle_device = get_idle(device_ids)
        if idle_device is not None:
            print(idle_device)
            return idle_device

        time.sleep(3)
        if time.time() - base_time > timeout:
            return None



from setuptools import setup, find_packages
setup(
    name                = 'gpugrab',
    version             = '0.1.0',
    description         = 'get idle gpu deivce.',
    author              = 'seil.na',
    author_email        = 'seil.na@vision.snu.ac.kr',
    url                 = 'https://github.com/seilna/gpugrab',
    download_url        = 'https://github.com/seilna/gpugrab/archive/master.zip',
	install_requires	= ['pynvml'],
    packages            = find_packages(exclude = []),
    keywords            = ['gpu'],
    python_requires     = '>=3',
)
